#
# spec file for package ibus-rime
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ibus-rime
Version:        1.5.0
Release:        150400.1.7
Summary:        Rime for Linux/IBus
License:        GPL-3.0-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/rime/ibus-rime
Source:         %{URL}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  libboost_headers-devel
BuildRequires:  cmake >= 3.10
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(rime)

%description
Rime Input Method Engine for Linux/IBus

%prep
%setup -q

%build
%cmake \
  -DCMAKE_INSTALL_LIBEXECDIR=%{_libexecdir} \
  -DRIME_DATA_DIR=%{_datadir}/rime-data
%make_build

%install
%cmake_install

%files
%license LICENSE
%doc README.md
%dir %{_datadir}/rime-data
%{_ibus_componentdir}/rime.xml
%{_libexecdir}/ibus-rime/
%{_datadir}/ibus-rime/
%{_datadir}/rime-data/ibus_rime.yaml

%changelog
* Sat May  8 2021 rpm@fthiessen.de
- Drop outdated build requirements opencc and libkyotocabinet
- Fix minimum cmake version
* Thu Jan 28 2021 wsxy162@gmail.com
- Update to version 1.5.0
  * feat(ibus_rime.yaml): install config file for ibus-rime,
    set default UI style
  * feat(rime_settings): add config options: style/preedit_style,
    style/cursor_type
  * feat(plugins): use librime's internal plugin loader
  * fix(logging): wrong log file name
  * fix(rime_engine): ignore keys with super modifier
  * fix(rime_main): deploy ibus_rime.yaml on maintenance
  * submodules: migrate to rime/plum
* Tue Jan 19 2021 wsxy162@gmail.com
- Update to version 1.4.1~git20201204.bfabe67:
  * Delete install.sh
  * Delete install-static.sh
  * build: Substitute paths in rime.xml
  * build: Use CMake’s install manifest for uninstallation detection
  * build: Move install logic to CMake
  * docs(README.md): clarify license
- Remove Requires: brise, since it has been deprecated upstream
  and already recommended by librime
* Mon Nov  9 2020 hillwood@opensuse.org
- Set Requires tag for brise, ibus-rime need it. (boo#1178582)
* Mon Sep 28 2020 i@marguerite.su
- Update to version 1.4.1~git20200712.33b2755:
  * fix(rime_engine): ignore keys with super modifier
  * feat(ibus_rime.yaml): install config file for ibus-rime, set default UI style
  * fix(logging): wrong log file name
  * feat(rime_settings): add config options: style/preedit_style, style/cursor_type
  * fix(rime_settings.h): compile with gcc 10
  * feat(plugin): dynamically load librime plugins read from `ibus_rime.yaml` (#73)
  * chore(CHANGELOG.md): fix typo
  * chore(release): 1.4.0 :tada:
  * chore(README.md, rime.xml): use https link
  * fix(rime_main.cc): deploy ibus_rime.yaml on maintenance
* Wed Mar 27 2019 i@marguerite.su
- update License
- add Requires: rime since rime binaries were moved to a new package,
  and librime1 can't pull it in
* Mon Mar 25 2019 opensuse-packaging@opensuse.org
- Update to version 1.4.1~git20190223.c80c02f:
  * chore(CHANGELOG.md): fix typo
  * chore(release): 1.4.0 :tada:
  * chore(README.md, rime.xml): use https link
  * fix(rime_main.cc): deploy ibus_rime.yaml on maintenance
  * chore(rime.xml, rime_main.c): update ibus component name
  * refactor(rime_*.cc): adopt librime 1.x API
  * chore(release): 1.3.0 :tada:
  * chore(submodules): update librime, plum
  * fix(CMakeLists.txt): static build requires boost_locale and icuuc
  * chore(CHANGES.md): reformat change log
* Tue Feb  6 2018 dimstar@opensuse.org
- Don't BuildRequire libyaml-cpp0_5/libyaml-cpp0_3 (depending on
  version): explicitly buildrequiring a library is generally seen
  always wrong. The correct library is already pulled in by
  librime.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sun Aug 10 2014 i@marguerite.su
- update version 1.2
  * rime_engine.c: add status bar icons; update status bar
    only when there is a change in IME status, to fix issues
    on Ubuntu Trusty.
  * rime_config.h: define macros for version and file paths.
  * Makefile: fix file permissions in install target.
* Sat Mar 15 2014 i@marguerite.su
- update version 1.1git20140316
  * rime.xml: add symbolic icon for GNOME Shell.
  * rime_settings.*: fallback to ibus default UI options in 'panel' section.
* Sat Nov 16 2013 hillwood@linuxfans.org
- Update to 1.0
  * add config option 'lookup_table_orientation'.
* Sat Jul  6 2013 hillwood@linuxfans.org
- Ｕpdate to 0.9.9
  * support static linking librime and its dependencies.
  * support changing conversion mode with Caps Lock.
  * add 'Sync data' button.
  * in Chinese mode, display the name of schema on status bar.
  * display notifications about deployment result.
* Tue Oct 16 2012 hillwood@linuxfans.org
- Update to 0.9.4
  * user dictionary for table input method.
  * automatically build schema dependencies.
  * logging with google-glog.
  * install data files from a separate package: brise.
  * new API: accessing schema list.
  * new API: enabling/disabling soft cursor in preedit string.
* Tue Jul 24 2012 hillwood@linuxfans.org
- The first version 0.9.2
  * UI: new Rime logo.
  * UI: Add Chinese/ascii mode indicator and Deploy button to status bar.
  * UI: Show notification when deploying Rime.
